Crate read_stdin
read_
stdin
1.1.1
All Items
Crate Items
Functions
Crate
read_
stdin
Functions

once
Read user input from
stdin
and try to parse it into a generic type.
prompt
Creates a CLI prompt and asks the user for input.
prompt_
until_
ok
Creates a CLI prompt and repeatetly asks the user for input until their input is of valid type.
read_
stdin
Deprecated
read_
stdin_
until_
ok
Deprecated
until_
ok
Read user input from
stdin
and try to parse it into a generic type. I will keep prompting the user for input until they enter data that properly parses.